@@ -7,7 +7,7 @@ class ModelCodeBlock(Model):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        if self.code == None:
+        if self.code is None:
             raise Exception(f'Не задан код.')
 
     def __str__(self):
