@@ -26,7 +26,7 @@ class WinAppModel(Model):
     def __init__(self, *args: object, **kwargs: object):
         super().__init__(*args, **kwargs)
 
-        if self.name == None:
+        if self.name is None:
             raise Exception(f'Не задано имя модели.')
 
         logger.debug(f'Инициализация приложения: {self.dbl_qutes_str(self.name)}')
