@@ -80,7 +80,12 @@ def get_drive_leter(path):
 
 
 def replace_alt_set(path):
-    return path.replace(os.altsep, os.sep).replace(f'{os.sep}{os.sep}', os.sep)
+    from isc_common.fields.files import FieldFileEx
+    if isinstance(path, FieldFileEx):
+        path = path.path
+        return path.replace(os.altsep, os.sep).replace(f'{os.sep}{os.sep}', os.sep)
+    else:
+        return path.replace(os.altsep, os.sep).replace(f'{os.sep}{os.sep}', os.sep)
 
 
 def replace_sep(path):
@@ -279,7 +284,7 @@ class Stack:
         return [item for item in self.stack if function(item)].copy()
 
     def exists(self, function):
-        return len([item for item in self.stack if function(item)]) > 0
+        return len(self.find(function=function)) > 0
 
     def print_all(self):
         if self.size() > 0:
@@ -299,7 +304,7 @@ class Stack:
         return res[0]
 
     def __str__(self):
-        return "\n".join([str(item) for item in self.stack])
+        return "[" + ",".join([str(item) for item in self.stack]) + "]"
 
 
 class StackLocs(Stack):
@@ -329,6 +334,49 @@ class StackLocs(Stack):
             pass
 
 
+class StackWithId(Stack):
+    def __init__(self, id='id'):
+        self.id = id
+        super().__init__()
+
+    def push(self, item, logger=None):
+
+        if not isinstance(item, dict):
+            raise Exception(f'{item} must be dict')
+        if not self.exists(item.get(self.id)):
+            self.stack.append(item)
+            if isinstance(logger, Logger):
+                logger.debug(f'self.stack.append: {item}')
+                logger.debug(f'self.stack.size: {self.size()}')
+            return True
+        else:
+            raise Exception(f'{item} will be doublicate')
+
+        if isinstance(logger, Logger):
+            logger.debug(f'size stack: {len(self.stack)}')
+        return True
+
+    def exists(self, id):
+        return len(self.find(id)) > 0
+
+    def find(self, id):
+        if not isinstance(id, int):
+            raise Exception(f'{id} must be int')
+        return list(filter(lambda x: x.get(self.id) == id, self.stack))
+
+    def find_one(self, id):
+        if not isinstance(id, int):
+            raise Exception(f'{id} must be int')
+
+        res = self.find(id=id).copy()
+        if len(res) == 0:
+            raise StackElementNotExist()
+        elif len(res) > 1:
+            raise MultipleStackElement()
+
+        return res[0]
+
+
 def get_list_nums_key_dict(data):
     res = []
     if isinstance(data, dict):
@@ -360,3 +408,25 @@ class Wrapper:
 
 
 user_name_anonim = "anonim"
+
+
+def delNonePropFromDict(in_dict):
+    if not isinstance(in_dict, dict):
+        raise Exception(f'{in_dict} must be dict')
+
+    res = dict()
+    for k, v in in_dict.items():
+        if v is not None:
+            setAttr(res, k, v)
+    return res
+
+
+def delZeroPropFromDict(in_dict):
+    if not isinstance(in_dict, dict):
+        raise Exception(f'{in_dict} must be dict')
+
+    res = dict()
+    for k, v in in_dict.items():
+        if v != 0:
+            setAttr(res, k, v)
+    return res
