@@ -146,8 +146,8 @@ class LoginRequest(DSRequest):
         except User.DoesNotExist:
             self.response = dict(status=RPCResponseConstant.statusLoginIncorrect, errorMessage=errorMessage)
 
-    @staticmethod
-    def get_chats(user):
+    @classmethod
+    def get_chats(cls, user):
         tetatet_chats_reciver = []
         tetatet_chats_sender = []
         tetatet_chats = []
@@ -223,8 +223,8 @@ class LoginRequest(DSRequest):
             tetatet_chats=tetatet_chats,
         )
 
-    @staticmethod
-    def send_bot_message(user, bot, message, compulsory_reading=False):
+    @classmethod
+    def send_bot_message(cls, user, bot, message, compulsory_reading=False):
         _user = user
         _bot = bot
 
