@@ -14,8 +14,8 @@ logger = logging.getLogger(__name__)
 class UserManager(BaseUserManager):
     use_in_migrations = True
 
-    @staticmethod
-    def getRecord(**kwargs):
+    @classmethod
+    def getRecord(cls, **kwargs):
         record = kwargs.get('record')
         res = {
             "id": record.id,
@@ -37,8 +37,8 @@ class UserManager(BaseUserManager):
         }
         return res
 
-    @staticmethod
-    def getRecord1(record):
+    @classmethod
+    def getRecord1(cls, record):
         res = {
             "id": record.id,
             "username": record.username,
