@@ -13,6 +13,10 @@ logger = logging.getLogger(__name__)
 
 class LoggingRequestMiddleware(MiddlewareMixin):
     def process_request(self, request):
+
+        if request.content_type not in ['text/xml', 'application/json']:
+            return
+
         self.json = BytesToJson(request.body)
 
         if settings.INCLUDE_REQUEST_PATHES is None:
