@@ -17,8 +17,8 @@ class User(AbstractUser):
         ('bot', 'Системный пользователь'),  # 1
     ), default=0, db_index=True)
 
-    @staticmethod
-    def admin_user():
+    @classmethod
+    def admin_user(cls):
         admin_user, _ = User.objects.get_or_create(username='admin', defaults=dict(password='admin'))
         return admin_user
 
