@@ -10,7 +10,7 @@ class Field(models.Field):
         ]
 
     def _check_verbose_name(self, **kwargs):
-        if self.verbose_name == None:
+        if self.verbose_name is None:
             return [
                 checks.Error(
                     "Fields must define a 'verbose_name' attribute.",
