@@ -14,8 +14,8 @@ class Standard_colorsQuerySet(BaseRefQuerySet):
 
 class Standard_colorsManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
