@@ -17,7 +17,7 @@ def del_last_zero(value):
     cel = res.split('.')[0]
     float = res.split('.')[1:4][0].rstrip('0')
     float = StrToNumber(float)
-    if float > 0:
+    if isinstance(float, int) and float > 0:
         return f'{cel}.{float}'
     return cel
 
