@@ -4,6 +4,7 @@ import traceback
 from contextlib import contextmanager
 
 from django.conf import settings
+from django.db import transaction
 from django.utils import timezone
 from tqdm import tqdm
 
@@ -220,15 +221,17 @@ class Progress:
     def setContentsLabel(self, content):
         if self.progress is not None:
             self.progress.setContentsLabel(labelContents=content, id=self.id)
-            self.progresses.label_contents = content
-            self.progresses.save()
+            with transaction.atomic():
+                self.progresses.label_contents = content
+                self.progresses.save()
 
     def setQty(self, qty):
         if self.progress is not None:
             self.qty = qty
             self.progress.setCntAll(cntAll=qty, id=self.id)
-            self.progresses.qty = qty
-            self.progresses.save()
+            with transaction.atomic():
+                self.progresses.qty = qty
+                self.progresses.save()
 
     def sendInfo(self, message):
         if self.progress is not None:
