@@ -55,16 +55,16 @@ class MessagesQuerySet(AuditQuerySet):
 
 class MessagesManager(CommonTreeGridManager):
 
-    @staticmethod
-    def get_tracker_bot():
+    @classmethod
+    def get_tracker_bot(cls):
         key = 'MessagesManager.get_tracker_bot'
         settings.LOCKS.acquire(key)
         tracker_bot, _ = User.objects.get_or_create(username='tracker_bot', last_name='Бот (Дела)', password='1234567890', props=User.props.bot, deliting=False, editing=False)
         settings.LOCKS.release(key)
         return tracker_bot
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'date_create': record.lastmodified,
             'deliting': record.deliting,
@@ -112,8 +112,8 @@ class MessagesManager(CommonTreeGridManager):
         delAttr(data, 'httpHeaders')
         return super().create(**data)
 
-    @staticmethod
-    def get_border(message, user=None):
+    @classmethod
+    def get_border(cls, message, user=None):
         if isinstance(user, int):
             color = User.objects.get(id=user).color
             return f'<div style="border: 1px solid {color if color else "black"};" class="outline">{message}</div>'
