@@ -14,8 +14,8 @@ logger = logging.getLogger(__name__)
 
 
 class Messages_theme_Manager(CommonTreeGridManager):
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "code": record.code,
@@ -70,8 +70,8 @@ class Messages_theme(BaseRefHierarcy):
     code = CodeField(unique=True)
     creator = ForeignKeyCascade(User, null=True, blank=True)
 
-    @staticmethod
-    def auto_from_error():
+    @classmethod
+    def auto_from_error(cls):
         return Messages_theme.objects.get_or_create(
             code='auto_from_error',
             defaults=dict(
@@ -81,8 +81,8 @@ class Messages_theme(BaseRefHierarcy):
                 deliting=False,
                 description='Тема создана автоматически'))[0]
 
-    @staticmethod
-    def chats_theme():
+    @classmethod
+    def chats_theme(cls):
         return Messages_theme.objects.get_or_create(
             code='chats',
             defaults=dict(
@@ -92,8 +92,8 @@ class Messages_theme(BaseRefHierarcy):
                 deliting=False,
                 description='Тема создана автоматически'))[0]
 
-    @staticmethod
-    def group_chats_theme():
+    @classmethod
+    def group_chats_theme(cls):
         return Messages_theme.objects.get_or_create(
             code='group_chats',
             defaults=dict(
@@ -104,8 +104,8 @@ class Messages_theme(BaseRefHierarcy):
                 parent=Messages_theme.chats_theme(),
                 description='Тема создана автоматически'))[0]
 
-    @staticmethod
-    def tetatet_chats_theme():
+    @classmethod
+    def tetatet_chats_theme(cls):
         return Messages_theme.objects.get_or_create(
             code='tetatet_chats',
             defaults=dict(
@@ -116,8 +116,8 @@ class Messages_theme(BaseRefHierarcy):
                 parent=Messages_theme.chats_theme(),
                 description='Тема создана автоматически'))[0]
 
-    @staticmethod
-    def system_chats_theme():
+    @classmethod
+    def system_chats_theme(cls):
         return Messages_theme.objects.get_or_create(
             code='system_chats',
             defaults=dict(
