@@ -20,8 +20,8 @@ class MessagesThemeUsersAccessQuerySet(AuditQuerySet):
 
 class MessagesThemeUsersAccessManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'theme_id': record.theme.id,
@@ -42,7 +42,7 @@ class MessagesThemeUsersAccessManager(AuditManager):
         _data = data.copy()
         props = _data.get('props')
 
-        if data.get('all_content') is True:
+        if data.get('all_content') == True:
             props |= MessagesThemeUsersAccess.props.all_content
         else:
             props &= ~MessagesThemeUsersAccess.props.all_content
