@@ -59,8 +59,8 @@ class Chat_user_userQuerySet(AuditQuerySet):
 
 class Chat_user_userManager(AuditManager):
 
-    @staticmethod
-    def get_next_common_id():
+    @classmethod
+    def get_next_common_id(cls, ):
         with connection.cursor() as cursor:
             cursor.execute("select max(common_id) + 1 from twits_chat_user_user")
             row = cursor.fetchone()
@@ -68,8 +68,8 @@ class Chat_user_userManager(AuditManager):
                 return 1
             return row[0]
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'common_id': record.common_id,
@@ -162,8 +162,8 @@ class Chat_user_userManager(AuditManager):
                 res += qty
             return res
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('compulsory_reading', 'Обязательное прочтение'),  # 1
         ), default=0, db_index=True)
