@@ -62,8 +62,8 @@ class Chat_user_userViewQuerySet(AuditQuerySet):
 
 class Chat_user_userViewManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'common_id': record.common_id,
