@@ -22,8 +22,8 @@ class Chat_usersViewQuerySet(AuditQuerySet):
 
 class Chat_usersViewManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             "user_id": record.user.id,
